scilpy.utils package
====================

scilpy.utils.filenames module
-----------------------------

.. automodule:: scilpy.utils.filenames
   :members:
   :undoc-members:
   :show-inheritance:

scilpy.utils.metrics\_tools module
----------------------------------

.. automodule:: scilpy.utils.metrics_tools
   :members:
   :undoc-members:
   :show-inheritance:

scilpy.utils.streamlines module
-------------------------------

.. automodule:: scilpy.utils.streamlines
   :members:
   :undoc-members:
   :show-inheritance:

scilpy.utils.util module
------------------------

.. automodule:: scilpy.utils.util
   :members:
   :undoc-members:
   :show-inheritance:
